@@ -65,7 +65,9 @@ def poly_to_geojson(poly: str):
     poly = poly.replace('\t',' ')
     lines = poly.split('\n')
     gjson['name'] = lines[0].strip()
-    for line in lines[2:len(lines)-2]:
+    for line in lines[2:]:
+        if line.strip() == 'END':
+            break
         coords = [x for x in line.strip().split(' ') if len(x) > 0]
         gjson['features'][0]['geometry']['coordinates'][0].append([float(coords[0]),float(coords[1])])
     return gjson
